<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>スクリーンショットを撮る</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="98"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ファイル1, ファイル2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../../upload/imageshackupload.cpp" line="49"/>
        <source>unknown error response</source>
        <translation>未知のエラー</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../../upload/imgurupload.cpp" line="46"/>
        <source>unknown error response</source>
        <translation>未知のエラー</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="145"/>
        <source>About</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="146"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - シンプルで高速な画像ビューワ

Copyright (C) 2013
LXQt Project: https://lxqt.org/

作者:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="255"/>
        <source>Open File</source>
        <translation>ファイルを開く</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="256"/>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Image files (%1)</source>
        <translation>画像ファイル (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="262"/>
        <source>Open directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="283"/>
        <source>Save File</source>
        <translation>ファイルの保存</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (ロード中...) - イメージビューア</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="544"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (ロードに失敗) - イメージビューア</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - イメージビューア</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="584"/>
        <source>[*]Image Viewer</source>
        <translation>[*]イメージビューア</translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (読み込み中...) - 画像ビューワ</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (読み込みに失敗) - 画像ビューワ</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (%2x%3) - 画像ビューワ</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">画像ビューワ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="851"/>
        <source>Thumbnails</source>
        <translation>サムネイル</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="48"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="124"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="127"/>
        <source>Stop</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="130"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../../upload/uploaddialog.cpp" line="137"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>画像ビューワ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="162"/>
        <source>&amp;About</source>
        <translation>このアプリケーションについて(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>&amp;Open File</source>
        <translation>ファイルを開く(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="175"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="188"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Save &amp;As</source>
        <translation>名前を付けて保存(&amp;A)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="201"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Zoom &amp;In</source>
        <translation>拡大(&amp;I)</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation type="vanished">Ctrl++</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Zoom &amp;Out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="240"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>クリップボードへコピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="260"/>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>Next File</source>
        <translation>次のファイル</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="vanished">右</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="276"/>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Previous File</source>
        <translation>前のファイル</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="vanished">左</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="227"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="266"/>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="282"/>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Original Size</source>
        <translation>原寸大</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="295"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="305"/>
        <source>&amp;Fit</source>
        <translation>フィット(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="315"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>時計方向に回転(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>反時計方向に回転(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="330"/>
        <source>P&amp;references</source>
        <translation>設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>&amp;Print</source>
        <translation>印刷(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="338"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>First File</source>
        <translation>最初のファイル</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>Last File</source>
        <translation>最後のファイル</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="364"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>&amp;New Window</source>
        <translation>新規ウィンドウ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="377"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="382"/>
        <source>Flip &amp;Horizontally</source>
        <translation>水平方向に反転(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="392"/>
        <source>Capture Screenshot</source>
        <translation>スクリーンショットを撮る</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F&amp;ull Screen</source>
        <translation>全画面(&amp;U)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="403"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="408"/>
        <source>Flip &amp;Vertically</source>
        <translation>垂直方向に反転(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="418"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>クリップボードからペースト(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="431"/>
        <source>&amp;Slide Show</source>
        <translation>スライドショー(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="444"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="452"/>
        <source>Show Thumbnails</source>
        <translation>サムネイルを表示</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="457"/>
        <source>File Properties</source>
        <translation>ファイルのプロパティ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="465"/>
        <source>Open &amp;Directory</source>
        <translation>ディレクトリを開く(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="468"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="476"/>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="479"/>
        <source>Upload the image</source>
        <translation>画像をアップロード</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>移動</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="123"/>
        <source>Toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="vanished">ツールバー</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>アイコンテーマ:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>通常の背景色:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>フルスクリーン時の背景色:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>スライドショーの間隔(秒):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TODO: Add configuration options here</source>
        <translation type="vanished">TODO: Add configuration options here</translation>
    </message>
    <message>
        <source>Tab 1</source>
        <translation type="vanished">タブ 1</translation>
    </message>
    <message>
        <source>Tab 2</source>
        <translation type="vanished">タブ 2</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>スクリーンショット</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>スクリーンショットを撮る</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>領域</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>画面全体</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>現在のウィンドウのみ</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>スクリーンの範囲をキャプチャーする</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>マウスカーソルを含む</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>遅延:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>ウィンドウのタイトルと枠を含む</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
</context>
</TS>
